"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebSocketServerTransport = void 0;
const ws_1 = __importDefault(require("ws"));
const ataraxia_transport_1 = require("ataraxia-transport");
const ataraxia_ws_client_1 = require("ataraxia-ws-client");
class WebSocketServerTransport extends ataraxia_transport_1.AbstractTransport {
    constructor(options) {
        super('ws-server');
        if (!options) {
            throw new Error('WebSocketServerTransport requires options, such as a port');
        }
        this.options = options;
    }
    async start(options) {
        const started = await super.start(options);
        if (!started)
            return false;
        this.server = new ws_1.default.Server(this.options);
        this.server.on('connection', socket => {
            const peer = new WebsocketServerPeer(this.transportOptions, this.options.authentication);
            this.addPeer(peer);
            peer.setSocket(socket);
        });
        this.server.on('error', err => {
            this.debug('Ignoring error:', err);
        });
        if (!this.options.server && !this.options.noServer) {
            // If not using an existing server wait until the server is started
            const server = this.server;
            return new Promise(resolve => server.on('listening', () => resolve(true)));
        }
        return true;
    }
    async stop() {
        const stopped = await super.stop();
        if (!stopped)
            return false;
        if (this.server) {
            const server = this.server;
            await new Promise(resolve => server.close(() => resolve(undefined)));
            this.server = undefined;
        }
        return true;
    }
}
exports.WebSocketServerTransport = WebSocketServerTransport;
class WebsocketServerPeer extends ataraxia_ws_client_1.AbstractWebSocketPeer {
    setSocket(socket) {
        super.setSocket(socket);
        this.negotiateAsServer();
    }
}
//# sourceMappingURL=WebSocketServerTransport.js.map